---
title: Introduction
description: 'Deep learning at the speed of light.'
icon: 'hand-wave'
---

<img
  className="block dark:hidden rounded-xl"
  src="/images/abstract_light.jpg"
  alt="Hero Light"
/>
<img
  className="hidden dark:block rounded-xl"
  src="/images/abstract.jpg"
  alt="Hero Dark"
/>

Luminal is a new machine learning framework focused on **speed**, **simplicity** and **composability**. We take a new approach to ML by focusing on static graphs and leaning heavily on compilers.

## Contents

Navigate around the Luminal docs.

<CardGroup cols={2}>
  <Card
    title="Quickstart"
    icon="bolt"
    href="/docs/quickstart"
  >
    Get up and running ML models in a flash.
  </Card>
  <Card
    title="Why Luminal"
    icon="lightbulb"
    href="/docs/why"
  >
    Dive into why Luminal was created and the design philosophy behind it.
  </Card>
  <Card
    title="GraphTensor API"
    icon="webhook"
    href="/docs/graphtensor"
  >
    High-level interface for building models.
  </Card>
  <Card
    title="Modules"
    icon="shapes"
    href="/docs/modules"
  >
    Composable building blocks of complex neural networks.
  </Card>
  <Card
    title="Compilers"
    icon="microchip"
    href="/docs/compilers"
  >
    Core transformations of the computation graph.
  </Card>
  <Card
    title="Developers"
    icon="code"
    href="/developers"
  >
    Resources for contributors and future development.
  </Card>
  <Card
    title="Blog"
    icon="newspaper"
    href="/blog"
  >
    Lessons and milestones on the way to the future of ML.
  </Card>
  <Card
    title="Community"
    icon="people-group"
    href="https://discord.gg/VQf3j8WWNd"
  >
    Come join a group of builders working on ambitious problems.
  </Card>
</CardGroup>